Exception: LastFM12::AdjustingError
- Defined in:
- lib/lastfm12.rb
Overview
Exception class for errors of adjusting radion station There ar 9 exception messages:
- There is not enough content to play the station. Due to restrictions imposed by the music labels, a radio station must have more than 15 tracks; each by different artists.
- The group does not have enough members to have a radio station.
- The stream has stopped. Please try again later, or try another station.
- The user does not have enough neighbors to have a radio station.
- The station is available to subscribers only.
- The station is not available for streaming.
- The artist does not have enough fans to have a radio station.
- An unknown error occurred. referred to on adjust.php error codes
Constant Summary collapse
- Messages =
['There is not enough content to play the station. Due to restrictions imposed by the music labels, a radio station must have more than 15 tracks; each by different artists.', 'The group does not have enough members to have a radio station.', 'The artist does not have enough fans to have a radio station.', 'The station is not available for streaming.', 'The station is available to subscribers only.', 'The user does not have enough neighbors to have a radio station.', 'An unknown error occurred.']